==> pmml-model-gwt-1.5.11.jar: org/dmg/pmml/Counts.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import org.dmg.pmml.adapters.NonNegativeIntegerAdapter;
import org.dmg.pmml.adapters.NumberAdapter;
import org.jpmml.model.annotations.Added;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "Counts", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions"
})
@JsonRootName("Counts")
@JsonPropertyOrder({
    "totalFreq",
    "missingFreq",
    "invalidFreq",
    "cardinality",
    "extensions"
})
public class Counts
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<Counts>
{

    @XmlAttribute(name = "totalFreq", required = true)
    @XmlJavaTypeAdapter(NumberAdapter.class)
    @JsonProperty("totalFreq")
    private Number totalFreq;
    @XmlAttribute(name = "missingFreq")
    @XmlJavaTypeAdapter(NumberAdapter.class)
    @JsonProperty("missingFreq")
    private Number missingFreq;
    @XmlAttribute(name = "invalidFreq")
    @XmlJavaTypeAdapter(NumberAdapter.class)
    @JsonProperty("invalidFreq")
    private Number invalidFreq;
    @XmlAttribute(name = "cardinality")
    @XmlJavaTypeAdapter(NonNegativeIntegerAdapter.class)
    @XmlSchemaType(name = "nonNegativeInteger")
    @Added((org.dmg.pmml.Version.PMML_4_0))
    @JsonProperty("cardinality")
    private Integer cardinality;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    private final static long serialVersionUID = 67371266L;

    public Counts() {
    }

    @ValueConstructor
    public Counts(
        @org.jpmml.model.annotations.Property("totalFreq")
        Number totalFreq) {
        this.totalFreq = totalFreq;
    }

    public Number getTotalFreq() {
        return totalFreq;
    }

    public Counts setTotalFreq(
        @org.jpmml.model.annotations.Property("totalFreq")
        Number totalFreq) {
        this.totalFreq = totalFreq;
        return this;
    }

    public Number getMissingFreq() {
        return missingFreq;
    }

    public Counts setMissingFreq(
        @org.jpmml.model.annotations.Property("missingFreq")
        Number missingFreq) {
        this.missingFreq = missingFreq;
        return this;
    }

    public Number getInvalidFreq() {
        return invalidFreq;
    }

    public Counts setInvalidFreq(
        @org.jpmml.model.annotations.Property("invalidFreq")
        Number invalidFreq) {
        this.invalidFreq = invalidFreq;
        return this;
    }

    public Integer getCardinality() {
        return cardinality;
    }

    public Counts setCardinality(
        @org.jpmml.model.annotations.Property("cardinality")
        Integer cardinality) {
        this.cardinality = cardinality;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public Counts addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.6.11.jar: org/dmg/pmml/Counts.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.dmg.pmml.adapters.NonNegativeIntegerAdapter;
import org.dmg.pmml.adapters.NumberAdapter;
import org.jpmml.model.MissingAttributeException;
import org.jpmml.model.annotations.Added;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "Counts", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions"
})
@JsonRootName("Counts")
@JsonPropertyOrder({
    "totalFreq",
    "missingFreq",
    "invalidFreq",
    "cardinality",
    "extensions"
})
public class Counts
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<Counts>
{

    @XmlAttribute(name = "totalFreq", required = true)
    @XmlJavaTypeAdapter(NumberAdapter.class)
    @JsonProperty("totalFreq")
    private Number totalFreq;
    @XmlAttribute(name = "missingFreq")
    @XmlJavaTypeAdapter(NumberAdapter.class)
    @JsonProperty("missingFreq")
    private Number missingFreq;
    @XmlAttribute(name = "invalidFreq")
    @XmlJavaTypeAdapter(NumberAdapter.class)
    @JsonProperty("invalidFreq")
    private Number invalidFreq;
    @XmlAttribute(name = "cardinality")
    @XmlJavaTypeAdapter(NonNegativeIntegerAdapter.class)
    @XmlSchemaType(name = "nonNegativeInteger")
    @JsonProperty("cardinality")
    @Added((org.dmg.pmml.Version.PMML_4_0))
    private Integer cardinality;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    private final static long serialVersionUID = 67371272L;

    public Counts() {
    }

    @ValueConstructor
    public Counts(
        @org.jpmml.model.annotations.Property("totalFreq")
        Number totalFreq) {
        this.totalFreq = totalFreq;
    }

    public Number requireTotalFreq() {
        if (this.totalFreq == null) {
            throw new MissingAttributeException(this, PMMLAttributes.COUNTS_TOTALFREQ);
        }
        return this.totalFreq;
    }

    public Number getTotalFreq() {
        return totalFreq;
    }

    public Counts setTotalFreq(
        @org.jpmml.model.annotations.Property("totalFreq")
        Number totalFreq) {
        this.totalFreq = totalFreq;
        return this;
    }

    public Number getMissingFreq() {
        return missingFreq;
    }

    public Counts setMissingFreq(
        @org.jpmml.model.annotations.Property("missingFreq")
        Number missingFreq) {
        this.missingFreq = missingFreq;
        return this;
    }

    public Number getInvalidFreq() {
        return invalidFreq;
    }

    public Counts setInvalidFreq(
        @org.jpmml.model.annotations.Property("invalidFreq")
        Number invalidFreq) {
        this.invalidFreq = invalidFreq;
        return this;
    }

    public Integer getCardinality() {
        return cardinality;
    }

    public Counts setCardinality(
        @org.jpmml.model.annotations.Property("cardinality")
        Integer cardinality) {
        this.cardinality = cardinality;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(!this.extensions.isEmpty()));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public Counts addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
